@@ -1,4 +1,3 @@
-from sqlalchemy.ext.declarative import declarative_base
 from skyext.db.postgre_db import Postgre
 
 __all__ = ('DataBase',)
@@ -26,7 +25,7 @@ class DataBase(object):
             "postgresql+psycopg2": DBFactory.create_pg,
             "mysql": DBFactory.create_mysql
         }
-        self._db = switch[self._protocol]()
+        self._db = switch[self._protocol](url=self._url)
 
     @property
     def model(self):
@@ -49,7 +48,9 @@ class DBFactory(object):
     def create_pg(cls, url=None, **kwargs):
         if not url:
             return
-        return Postgre().init(url=url, **kwargs)
+        _instance = Postgre()
+        _instance.init(url=url, **kwargs)
+        return _instance
 
     @classmethod
     def create_mysql(cls, config):
