@@ -24,7 +24,7 @@ class Session(object):
             "membercache": SessionFactory.create_member,
             "file": SessionFactory.create_file,
         }
-        self._client = switch[self._protocol]()
+        self._client = switch[self._protocol](url=self._url)
 
     def get(self, name):
         return self._client.get(name)
@@ -47,7 +47,9 @@ class SessionFactory(object):
     def create_redis(cls, url=None, **kwargs):
         if not url:
             return
-        return Redis().init(url=url, **kwargs)
+        _instance = Redis()
+        _instance.init(url=url, **kwargs)
+        return _instance
 
     @classmethod
     def create_member(cls, config):
